#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://ubuntrucchi.wordpress.com/progetti-projects/gwakeonlan/
# source location    : http://gwakeonlan.googlecode.com/files/gwakeonlan_0.4.1_all.tar.gz
# last revised       : 20.02.2010
# dep                : 

softname='gwakeonlan'
softversion='0.5'
packageversion='64.1'

arch='noarch'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname"-$softversion
srcpkg="$buildir/"$softname"-"$softversion"_all.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://gwakeonlan.googlecode.com/files/"$softname"-"$softversion"_all.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/gwakeonlan/
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
gwakeonlan: gwakeonlan (Turn on your machines on the net using the WOL)
gwakeonlan:
gwakeonlan: With gWakeOnLan you can turn on your turned off machines using the 
gwakeonlan: wake on lan feature.
gwakeonlan: Just a click to turn them all simultaneously.
gwakeonlan: 
gwakeonlan: 
gwakeonlan:
gwakeonlan:
gwakeonlan:
gwakeonlan:
EOF

# check if source is present
if [ -f "$softname"-"$softversion"_all.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# build
sed -i -e "s|share/doc/gwakeonlan|doc/gwakeonlan-0.5|g" $src/setup.py
sed -i -e "s|'doc/translators'|'doc/translators', 'doc/copyright'|g" $src/setup.py
patch -p0 < ../gwakeonlan.path

./setup.py install  --root=$dest --prefix=/usr

# fix icon
mkdir -p $dest/usr/share/icons/hicolor/scalable/apps/
mv $dest/usr/share/gwakeonlan/$softname.svg $dest/usr/share/icons/hicolor/scalable/apps/
cd $dest/usr/share/gwakeonlan/
ln -s ../icons/hicolor/scalable/apps/$softname.svg $softname.svg
convert $dest/usr/share/icons/hicolor/scalable/apps/$softname.svg -resize 48x48 $dest/usr/share/icons/hicolor/48x48/apps/$softname.png 

# desktop compliance
sed -i -e "s|/usr/bin/gwakeonlan|gwakeonlan|g" $dest/usr/share/applications/gwakeonlan.desktop
sed -i -e "s|/usr/share/gwakeonlan/gwakeonlan.svg|gwakeonlan|g" $dest/usr/share/applications/gwakeonlan.desktop

#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( mv $dest/$prefix/share/man $dest/$prefix/
  cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp gwakeonlan.path $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "python,pygtk,pygobject,pycairo" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/gwakeonlan/source/build-gwakeonlan.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
